.. _index:

TrackApps
=========

TrackApps extension provides interface to bugtracking and test management applications.

Following applications are supported.

* Quality Center - bugtracking, test management
* Bugzilla - bugtracking
* Mantis - bugtracking
* Trac - bugtracking
* Jira - bugtracking
* TestLink - test management

.. toctree::
   :hidden:
   
   rst/install
   rst/tutor
   rst/module
   rst/refman